(function( $ ) {
  'use strict';

  // Gallery add image functionality
  $('#game_showcase_admin_gallery_button').ready(() => {
    let meta_gallery_frame;

    $('#game_showcase_admin_gallery_button').click(function(e) {
      e.preventDefault();

      // If image upload frame already exists, reopen it
      if ( meta_gallery_frame ) {
        meta_gallery_frame.open();
        return;
      }

      // Set up a new image upload frame
      meta_gallery_frame = wp.media.frames.meta_gallery_frame = wp.media({
        title: 'Select Images for Gallery',
        button: { text: 'Add to gallery' },
        library: { type: 'image' },
        multiple: true
      });

      // Add a new state to the frame for our selection behavior
      meta_gallery_frame.states.add([
        new wp.media.controller.Library({
          id: 'game-showcase-gallery',
          title: 'Select Images',
          priority: 20,
          toolbar: 'main-gallery',
          filterable: 'uploaded',
          library: wp.media.query( meta_gallery_frame.options.library ),
          multiple: meta_gallery_frame.options.multiple ? 'reset' : false,
          editable: true,
          allowLocalEdits: true,
          displaySettings: true,
          displayUserSettings: true
        }),
      ]);

      // When frame is opened, select the selected images
      meta_gallery_frame.on('open', function() {
        const selection = meta_gallery_frame.state().get('selection');
        const library = meta_gallery_frame.state('gallery-edit').get('library');
        const ids = $('#gallery').val();
        if (ids) {
          let idsArray = ids.split(',');
          idsArray.forEach(function(id) {
            let attachment = wp.media.attachment(id);
            attachment.fetch();
            selection.add( attachment ? [ attachment ] : [] );
          });
        }
      });

      // Remove sidebar from image upload frame
      meta_gallery_frame.on('ready', function() {
        $('.media-modal').addClass('no-sidebar');
        $('.media-frame').addClass('hide-menu');
      });

      // Logic for saving the selection
      meta_gallery_frame.on('select', function() {
        const images = meta_gallery_frame.state().get('selection');
        let imageIDArray = [];
        let imageHTML = '';
        let metadataString = '';

        imageHTML += '<ul class="game_showcase_admin_gallery_list">';
        images.each(function(attachment) {
          imageIDArray.push(attachment.attributes.id);
          imageHTML += `<li>
            <div class="game_showcase_admin_gallery_container">
              <span class="game_showcase_admin_gallery_close">
              <img id="${attachment.attributes.id}" src="${attachment.attributes.sizes.thumbnail.url}">
              </span>
            </div>
          </li>`;
        });
        imageHTML += '</ul>';

        metadataString = imageIDArray.join(",");
        if (metadataString) {
          $("#gallery").val(metadataString);
          $("#game_showcase_admin_gallery_src").html(imageHTML);
        }
      });

      // Finally, open the upload frame
      meta_gallery_frame.open();
    });
  });

  // Gallery remove image functionality
  $('.game_showcase_admin_gallery_close').ready(() => {
    $('.game_showcase_admin_gallery_close').click(function(e) {
      event.preventDefault();

      if (confirm('Are you sure you want to remove this image?')) {
        var removedImage = $(this).children('img').attr('id');
        var oldGallery = $("#gallery").val();
        var newGallery = oldGallery.replace(','+removedImage,'').replace(removedImage+',','').replace(removedImage,'');
        jQuery(this).parents().eq(1).remove();
        jQuery("#gallery").val(newGallery);
      }
    });
  });

})( jQuery );
