<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://eriksaulnier.com/
 * @since             1.0.0
 * @package           Game_Showcase
 *
 * @wordpress-plugin
 * Plugin Name:       Game Showcase
 * Description:       Adds the ability to showcase games on your site.
 * Version:           1.2.3
 * Author:            Erik Saulnier
 * Author URI:        https://eriksaulnier.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       game-showcase
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
  die;
}

define( 'GAME_SHOWCASE_VERSION', '1.2.3' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-game-showcase-activator.php
 */
function activate_game_showcase() {
  require_once plugin_dir_path( __FILE__ ) . 'includes/class-game-showcase-activator.php';
  Game_Showcase_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-game-showcase-deactivator.php
 */
function deactivate_game_showcase() {
  require_once plugin_dir_path( __FILE__ ) . 'includes/class-game-showcase-deactivator.php';
  Game_Showcase_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_game_showcase' );
register_deactivation_hook( __FILE__, 'deactivate_game_showcase' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-game-showcase.php';

// Enable shortcodes in text widgets
add_filter('widget_text','do_shortcode');

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_game_showcase() {
  $plugin = new Game_Showcase();
  $plugin->run();
}
run_game_showcase();
