<?php

/**
 * Register all actions and filters for the plugin.
 *
 * Maintain a list of all hooks that are registered throughout
 * the plugin, and register them with the WordPress API. Call the
 * run function to execute the list of actions and filters.
 *
 * @package    Game_Showcase
 * @subpackage Game_Showcase/includes
 * @author     Erik Saulnier <info@eriksaulnier.com>
 */
class Game_Showcase_Widget extends WP_Widget {
  /**
  * Constructor for the widget
  */
  public function __construct() {
    parent::__construct(
      'game-showcase-widget',
      'Game Filters',
      array(
        'description' => __( 'Displays checkbox filters for searching the site\'s game archive', 'game-showcase' )
      )
    );
  }

  /**
  * Admin form in the widget area
  */
  public function form( $instance ) {
    $title = ( !empty($instance) ? strip_tags($instance['title']) : '' );
    ?>

    <p>
      <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
      <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>

    <?php
  }

  /**
  * Update function for the widget
  */
  public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;
    $instance['title'] = strip_tags($new_instance['title']);
    return $instance;
  }

  /**
  * Outputs the widget with the selected settings
  */
  public function widget( $args, $instance ) {
    extract($args);

    $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

    echo $before_widget;
    ?>
      <?php echo $before_title . $title . $after_title ?>

      <form action="" method="post" class="game-filters">
        <input type="hidden" name="post_type" value="game" />

        <ul>
          <li>
            <input type="text" name="search" class="form-control" placeholder="Search" value="<?php echo showcase_wall_search_query(); ?>" />
          </li>
          <li>
            <?php echo $this->build_taxonomy_checkboxes( 'Showcases', 'game_showcase', 'ID', 'DESC', false, false ); ?>
          </li>
          <li>
            <?php echo $this->build_taxonomy_checkboxes( 'Genres', 'game_genre', 'name', 'ASC', false, true ); ?>
          </li>
          <li>
            <input type="hidden" name="submitted" value="1" />
            <button type="submit" class="btn btn-secondary"><i class="fa fa-filter" aria-hidden="true"></i> Filter</button>
          </li>
        </ul>
      </form>
    <?php
    echo $after_widget;
  }

  public function build_taxonomy_checkboxes( $label, $taxonomy, $order_by = 'name', $order_dir = 'ASC', $show_empty = false, $show_count = false) {
    $taxonomy_data = get_taxonomy($taxonomy);
    $return_data = '';

    if ( $taxonomy_data ) {
      // Set taxonomy query args
      $query_args = array(
        'taxonomy' => $taxonomy,
        'hierarchical' => false,
        'child_of' => 0,
        'echo' => false,
        'hide_if_empty' => false,
        'hide_empty' => !$show_empty,
        'order' => $order_dir,
        'orderby' => $order_by,
        'show_option_none' => '',
        'show_count' => $show_count,
        'show_option_all' => '',
        'show_option_all_sf' => ''
      );

      $taxonomy_items = get_terms($query_args);

			if ( !empty($taxonomy_items) ) {
				// Attach heading
	      $return_data .= "<h4 class='taxonomy-title'>$label</h4>";

				$active = explode('+', get_query_var($taxonomy));
				if (count($active) == 1) {
					$active = explode(',', get_query_var($taxonomy));
				}

				$return_data .= "<ul class='taxonomy-values'>";

				foreach ($taxonomy_items as $item) {
					if (in_array($item->slug, $active)) {
						$checked = true;
					} else {
						$checked = false;
					}

					$return_data .= "<li class='checkbox'><label><input type='checkbox' name='".$taxonomy."[]' value='$item->slug'" . ($checked ? " checked='checked'" : '') . "' />$item->name";

					if ($show_count) {
						$return_data .= ' ('.intval($item->count).')';
					}

					$return_data .= "</label></li>";
				}
			}

      $return_data .= "</ul>";
    }

    return $return_data;
  }

}
