<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://eriksaulnier.com
 * @since      1.0.0
 *
 * @package    Game_Showcase
 * @subpackage Game_Showcase/public/partials
 */

$authors = get_post_meta(get_the_ID(), 'game_information_authors', true);
$genres = wp_get_post_terms(get_the_ID(), 'game_genre');
$play_link = get_post_meta(get_the_ID(), 'game_information_link', true);
$external_link = get_post_meta(get_the_ID(), 'game_information_website', true);

$days_since_posted = round( (current_time('timestamp') - get_the_date('U')) / (24*60*60) );
$flag_dev = get_post_meta(get_the_ID(), 'game_information_flag_dev', true);
$flag_new = $days_since_posted < 60 && !$flag_dev;
?>

<?php get_header(); ?>

<div class="wrap">

  <?php while ( have_posts() ) : the_post() ?>

    <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

      <header class="entry-header">

        <h1 class="entry-title"><?php the_title( '<h1 class="entry-title">', sprintf( '%s%s</h1>', $flag_new ? '<span class="badge badge-primary">New</span>' : '', $flag_dev ? '<span class="badge badge-secondary">In Development</span>' : '' ) ); ?></h1>

        <?php if ( $authors ) : ?>

          <div class="entry-meta">

            Game by <span class="author"><b><?php echo $authors; ?></b></span>

          </div>

        <?php endif; ?>

      </header>

      <div class="entry-content">

        <?php the_content(); ?>

      </div>

      <?php if ( !empty( $genres ) ) : ?>

        <h4 class="game-genre-title">Genres</h4>
        <ul class="game-genre-list">

          <?php foreach ( $genres as $genre ) : ?>

            <li>
              <a class="game-genre-link" href="<?php echo esc_url( get_term_link( $genre ) ); ?>">
                <?php echo $genre->name; ?>
              </a>
            </li>

          <?php endforeach; ?>

        </ul>

      <?php endif; ?>

      <?php if ( $play_link ) : ?>

        <a class="game-play-link" href="<?php echo esc_url( $play_link ); ?>">Play Game</a>

      <?php endif; ?>

      <?php if ( $external_link ) : ?>

        <a class="game-external-link" href="<?php echo esc_url( $external_link ); ?>">External Site</a>

      <?php endif; ?>

    </article>

    <?php if ( comments_open() || get_comments_number() ) {
      comments_template();
    } ?>

  <?php endwhile; ?>

</div>

<?php get_footer(); ?>
